@@ -16,6 +16,7 @@
 
 import datetime
 import json
+import warnings
 
 from girder_jobs.constants import JobStatus
 from girder_jobs.models.job import Job
@@ -23,7 +24,7 @@ from pkg_resources import DistributionNotFound, get_distribution
 
 import girder
 import large_image
-from girder import events
+from girder import events, logger
 from girder.constants import AccessType
 from girder.exceptions import ValidationException
 from girder.models.file import File
@@ -49,6 +50,11 @@ except DistributionNotFound:
     pass
 
 
+# Girder 3 is pinned to use pymongo < 4; its warnings aren't relevant until
+# that changes.
+warnings.filterwarnings('ignore', category=UserWarning, module='pymongo')
+
+
 def _postUpload(event):
     """
     Called when a file is uploaded. We check the parent item to see if it is
@@ -297,7 +303,10 @@ class LargeImagePlugin(GirderPlugin):
     CLIENT_SOURCE_PATH = 'web_client'
 
     def load(self, info):
-        getPlugin('worker').load(info)
+        try:
+            getPlugin('worker').load(info)
+        except Exception:
+            logger.debug('worker plugin is unavailable')
 
         unbindGirderEventsByHandlerName('large_image')
 
